summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorMichael BrĂ¼ning <michael.bruning@qt.io>2023-04-24 17:58:21 +0200
committerMichael BrĂ¼ning <michael.bruning@qt.io>2023-04-26 13:02:25 +0000
commit4ddfdfa0dbea7f71d5455cd3635049c95df45cce (patch)
tree6fcb2db82ca60f01db90c29788c5369fd83d1fb1
parente05471ecc625e9301e70ea809ada3388cb4fb8c4 (diff)
downloadqtwebengine-chromium-4ddfdfa0dbea7f71d5455cd3635049c95df45cce.tar.gz
Fixup 'Fixes for jumbo build'
The fix for jumbo builds renamed the function ProvideInputCallback to ProvideInputCallback2, but did not update the call site. This was probably hidden in jumbo builds as there is another function with the same signature in the decoder counterpart, but might have lead to some undefined / unwanted behaviour. Change-Id: I29129e5323bc3271016b7373cd49dc995749c7c9 Reviewed-on: https://codereview.qt-project.org/c/qt/qtwebengine-chromium/+/474116 Reviewed-by: Anu Aliyas <anu.aliyas@qt.io> Reviewed-by: Allan Sandfeld Jensen <allan.jensen@qt.io>
-rw-r--r--chromium/media/filters/mac/audio_toolbox_audio_encoder.cc4
1 files changed, 2 insertions, 2 deletions
diff --git a/chromium/media/filters/mac/audio_toolbox_audio_encoder.cc b/chromium/media/filters/mac/audio_toolbox_audio_encoder.cc
index 327aebf9741..6a40792d0b4 100644
--- a/chromium/media/filters/mac/audio_toolbox_audio_encoder.cc
+++ b/chromium/media/filters/mac/audio_toolbox_audio_encoder.cc
@@ -311,12 +311,12 @@ void AudioToolboxAudioEncoder::DoEncode(AudioBus* input_bus) {
output_buffer_list.mBuffers[0].mDataByteSize = max_packet_size_;
// Encodes |num_packets| into |packet_buffer| by calling the
// ProvideInputCallback to fill an AudioBufferList that points into
// |input_bus|. See media::AudioConverter for a similar mechanism.
UInt32 num_packets = 1;
AudioStreamPacketDescription packet_description = {};
auto result = AudioConverterFillComplexBuffer(
- encoder_, ProvideInputCallback, &input_data, &num_packets,
+ encoder_, ProvideInputCallback2, &input_data, &num_packets,
&output_buffer_list, &packet_description);
// We expect "1 in, 1 out" when feeding packets into the encoder, except
@@ -311,12 +311,12 @@ void AudioToolboxAudioEncoder::DoEncode(AudioBus* input_bus) {
output_buffer_list.mBuffers[0].mDataByteSize = max_packet_size_;
// Encodes |num_packets| into |packet_buffer| by calling the
- // ProvideInputCallback to fill an AudioBufferList that points into
+ // ProvideInputCallback2 to fill an AudioBufferList that points into
// |input_bus|. See media::AudioConverter for a similar mechanism.
UInt32 num_packets = 1;